@@ -15,7 +15,7 @@ except ImportError:
 from contextlib import contextmanager
 from .logger import configure
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 if PY3:
     unicode = str
@@ -35,6 +35,7 @@ for name in bindings:
 
     except ImportError:
         continue
+    break
 
 
 class LazyBinding(object):
@@ -313,6 +314,7 @@ class Ghost(object):
         download_images=True,
         show_scrollbars=True,
         network_access_manager_class=NetworkAccessManager,
+        web_page_class=GhostWebPage,
     ):
         if not binding:
             raise Exception("Ghost.py requires PySide or PyQt4")
@@ -341,7 +343,9 @@ class Ghost(object):
         ):
             try:
                 os.environ['DISPLAY'] = ':99'
-                Ghost.xvfb = subprocess.Popen(['Xvfb', ':99'])
+                process = ['Xvfb', ':99', '-pixdepths', '32']
+                FNULL = open(os.devnull, 'w')
+                Ghost.xvfb = subprocess.Popen(process, stdout=FNULL, stderr=subprocess.STDOUT)
             except OSError:
                 raise Error('Xvfb is required to a ghost run outside ' +
                             'an X instance')
@@ -364,7 +368,7 @@ class Ghost(object):
                     Ghost._app.addLibraryPath(p)
 
         self.popup_messages = []
-        self.page = GhostWebPage(Ghost._app, self)
+        self.page = web_page_class(Ghost._app, self)
 
         if network_access_manager_class is not None:
             self.page.setNetworkAccessManager(network_access_manager_class())
@@ -505,7 +509,17 @@ class Ghost(object):
             QtCore.Qt.Horizontal,
             QtCore.Qt.ScrollBarAlwaysOff,
         )
-        self.page.setViewportSize(self.main_frame.contentsSize())
+        frame_size = self.main_frame.contentsSize()
+        max_size = 23170 * 23170
+        if frame_size.height() * frame_size.width() > max_size:
+            self.logger.warn("Frame size is too large.")
+            default_size = self.page.viewportSize()
+            if default_size.height() * default_size.width() > max_size:
+                return None
+        else:
+            self.page.setViewportSize(self.main_frame.contentsSize())
+        self.logger.info("Frame size -> " + str(self.page.viewportSize()))
+
         image = QImage(self.page.viewportSize(), format)
         painter = QPainter(image)
 
@@ -1276,7 +1290,7 @@ class Ghost(object):
         if self.ignore_ssl_errors:
             reply.ignoreSslErrors()
         else:
-            self.warn('SSL certificate error: %s' % url)
+            self.logger.warn('SSL certificate error: %s' % url)
 
     def __enter__(self):
         return self
